import { createStore } from 'zustand/vanilla';
export * from 'zustand/vanilla';
import ReactExports from 'react';

const { useDebugValue, useMemo, useSyncExternalStore } = ReactExports;
const identity = (arg) => arg;
const useMemoSelector = (getState, selector) => useMemo(() => {
  let lastSlice;
  let lastState;
  return () => {
    const state = getState();
    if (!Object.is(lastState, state)) {
      lastSlice = selector(state);
      lastState = state;
    }
    return lastSlice;
  };
}, [getState, selector]);
function useStore(api, selector = identity) {
  const slice = useSyncExternalStore(
    api.subscribe,
    useMemoSelector(api.getState, selector),
    useMemoSelector(api.getInitialState, selector)
  );
  useDebugValue(slice);
  return slice;
}
const createImpl = (createState) => {
  const api = createStore(createState);
  const useBoundStore = (selector) => useStore(api, selector);
  Object.assign(useBoundStore, api);
  return useBoundStore;
};
const create = (createState) => createState ? createImpl(createState) : createImpl;

export { create, useStore };
