'use strict';

var vanilla = require('zustand/vanilla');
var ReactExports = require('react');

var useDebugValue = ReactExports.useDebugValue,
  useMemo = ReactExports.useMemo,
  useSyncExternalStore = ReactExports.useSyncExternalStore;
var identity = function identity(arg) {
  return arg;
};
var useMemoSelector = function useMemoSelector(getState, selector) {
  return useMemo(function () {
    var lastSlice;
    var lastState;
    return function () {
      var state = getState();
      if (!Object.is(lastState, state)) {
        lastSlice = selector(state);
        lastState = state;
      }
      return lastSlice;
    };
  }, [getState, selector]);
};
function useStore(api, selector) {
  if (selector === void 0) {
    selector = identity;
  }
  var slice = useSyncExternalStore(api.subscribe, useMemoSelector(api.getState, selector), useMemoSelector(api.getInitialState, selector));
  useDebugValue(slice);
  return slice;
}
var createImpl = function createImpl(createState) {
  var api = vanilla.createStore(createState);
  var useBoundStore = function useBoundStore(selector) {
    return useStore(api, selector);
  };
  Object.assign(useBoundStore, api);
  return useBoundStore;
};
var create = function create(createState) {
  return createState ? createImpl(createState) : createImpl;
};

exports.create = create;
exports.useStore = useStore;
Object.keys(vanilla).forEach(function (k) {
  if (k !== 'default' && !Object.prototype.hasOwnProperty.call(exports, k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return vanilla[k]; }
  });
});
